@@ -1,19 +1,20 @@
-#' @importFrom grDevices palette
-#' @importFrom graphics layout legend par plot text
-#' @export
+###' @importFrom grDevices palette
+###' @importFrom graphics layout legend par plot text
+###' @export
 plot.LexCHCca <-function(x, axes=c(1, 2), choice="tree", rect=TRUE, 
       title=NULL, ind.names=TRUE, new.plot=FALSE, max.plot=15, 
-      tree.barplot=TRUE,...) 
+      tree.barplot=TRUE, ...) 
 {
   if(is.null(x)) stop("Missing argument for x object")
   if (!inherits(x,"LexCHCca")) stop("x object should be LexCHCca class")   
-  res = x
-  X = res$call$X
+  res <- x
+  X <- res$call$X
   max<-res$call$max
   min<-res$call$min
-  max.plot = max(res$call$max,max.plot)
-  nb.clust = length(levels(X$clust))
-  levs = levels(X$clust)
+  max.plot <- max(res$call$max,max.plot)
+  nb.clust <- length(levels(X$clust))
+  levs <- levels(X$clust)
+
   
   if (choice == "tree") {
     if ((new.plot) & !nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) 
@@ -29,8 +30,7 @@ plot.LexCHCca <-function(x, axes=c(1, 2), choice="tree", rect=TRUE,
       layout(lay, respect = TRUE)
       inv.height = rev(res$call$t$height)
       vec<-inv.height[1:max.plot]
-      barplot(height = vec, col = c(rep("black", nb.clust - 
-                                          1), rep("grey", max(max, max.plot) - nb.clust + 1)), 
+      barplot(height = vec, col = c(rep("black", nb.clust - 1), rep("grey", max(max, max.plot) - nb.clust + 1)), 
               space = 0.7)
       plot(x = 1, xlab = "", ylab = "", main = "", col = "white", 
            axes = FALSE)
@@ -39,12 +39,13 @@ plot.LexCHCca <-function(x, axes=c(1, 2), choice="tree", rect=TRUE,
            axes = FALSE)
       legend("top", "Agg. criterion", box.lty = NULL, cex = 1)
     }
-    plot(res$call$t$tree, hang = -1, xlab = "", sub = "", 
-         ...)
+    
+
+    plot(res$call$t$tree, hang = -1, xlab = "", sub = "", ...)
+    
     if (rect) {
-      y = (res$call$t$tree$height[length(res$call$t$tree$height) - 
-                                    nb.clust + 2] + res$call$t$tree$height[length(res$call$t$tree$height) - 
-                                                                             nb.clust + 1])/2
+      y = (res$call$t$tree$height[length(res$call$t$tree$height) - nb.clust + 2] + 
+             res$call$t$tree$height[length(res$call$t$tree$height) - nb.clust + 1])/2
       ordColo <- unique(res$call$X$clust[res$call$t$tree$order])
       rect = rect.hclust(res$call$t$tree, h = y, border = ordColo)
     }
@@ -66,10 +67,10 @@ plot.LexCHCca <-function(x, axes=c(1, 2), choice="tree", rect=TRUE,
       if (ind.names) 
         plot.PCA(res2, title = title, habillage = ncol(Y), 
                  cex = 0.8, axes = axes, new.plot = new.plot, 
-                 palette = palette(), ...)
+                 palette = palette(), graph.type = "classic", ...)
       else plot.PCA(res2, title = title, habillage = ncol(Y), 
                     cex = 0.8, axes = axes, label = "none", new.plot = new.plot, 
-                    palette = palette(), ...)
+                    palette = palette(), graph.type = "classic", ...)
     }
   }
   if (choice == "bar") {
@@ -89,8 +90,6 @@ plot.LexCHCca <-function(x, axes=c(1, 2), choice="tree", rect=TRUE,
   if (choice == "tree" & tree.barplot) 
     par(def.par)
   invisible()
-  
-  
 }
 
 
